<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:java="http://xml.apache.org/xslt/java"
  xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
  extension-element-prefixes="java util"
  exclude-result-prefixes="java util">
 
  <xsl:template match="classifier">
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <xsl:variable name="cl_name"><xsl:value-of select="@name"/></xsl:variable>
    <xsl:choose>
      <xsl:when test="/page/pageResponse/service/classifierList/classifier[@name=$cl_name]/@horizontalAtTop">
	<xsl:apply-templates select="." mode="horizontal-at-top">
	  <xsl:with-param name="collName" select="$collName"/>
	  <xsl:with-param name="serviceName" select="$serviceName"/>
	</xsl:apply-templates>
      </xsl:when>
      <xsl:otherwise>
	<xsl:apply-templates select="." mode="default">
	  <xsl:with-param name="collName" select="$collName"/>
	  <xsl:with-param name="serviceName" select="$serviceName"/>
	</xsl:apply-templates>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  

  <xsl:template match="classifier" mode="horizontal-at-top">
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <xsl:choose>
      <xsl:when test="classifierNode">
	<table width='100%'>
	  <tr valign='top'>
	    <xsl:for-each select='classifierNode'>
	      <xsl:apply-templates select='.' mode="horizontal"><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates>
	    </xsl:for-each>
	  </tr>
	</table>
	<table width='100%'>
	  <tr valign='top'>
	    <xsl:for-each select='classifierNode'>
	      <xsl:apply-templates select='.' mode='process-all-children'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates>
	    </xsl:for-each>
	  </tr>
	</table>
	</xsl:when>
      <xsl:otherwise>
	<!-- there were no classifier nodes -->
	<table width='100%'>  
	  <xsl:for-each select='documentNode'>
	    <tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	  </xsl:for-each>
	</table>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:call-template name="dividerBar"/>
  </xsl:template>

  <xsl:template match="classifier" mode="default"> <!-- the default -->
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <table width='100%'>
      <xsl:for-each select='classifierNode|documentNode'>
	<tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	<xsl:if test='name()="classifierNode"'>
	  <!--recurse into the children-->
	  <tr valign='top'><td><xsl:text> </xsl:text></td><xsl:apply-templates select='.' mode='process-all-children'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	</xsl:if>
      </xsl:for-each>
    </table>
    <xsl:call-template name="dividerBar"/>
  </xsl:template>
  <!-- recursively process all nodes and documents -->
  
  <xsl:template match="documentNode">
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <td><a href="{$library_name}?a=d&amp;c={$collName}&amp;d={@nodeID}&amp;dt={@docType}&amp;p.a=b&amp;p.s={$serviceName}"><xsl:apply-templates select="." mode="displayNodeIcon"/></a></td><td align='left'><xsl:value-of disable-output-escaping="yes"  select="metadataList/metadata[@name='Title']"/></td>
  </xsl:template>
  
  <!-- icon + title template-->
  <xsl:template match="classifierNode">
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <td><a><xsl:attribute name='href'><xsl:value-of select='$library_name'/>?a=b&amp;rt=r&amp;s=<xsl:value-of select='$serviceName'/>&amp;c=<xsl:value-of select='$collName'/>&amp;cl=<xsl:value-of select='@nodeID'/><xsl:if test="classifierNode|documentNode">.pr</xsl:if></xsl:attribute><xsl:call-template name="bookshelfimg"/></a></td><td align='left'><xsl:value-of disable-output-escaping="yes" select="metadataList/metadata[@name='Title']"/></td>
  </xsl:template>
  
  <!-- the title is a link: an alternative template -->
  <xsl:template match="classifierNode" mode="horizontal">
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <xsl:choose>
      <xsl:when test="classifierNode|documentNode"><!-- the opened one -->
	<td><xsl:value-of disable-output-escaping="yes" select="metadataList/metadata[@name='Title']"/></td>
      </xsl:when>
      <xsl:otherwise>
	<td><a><xsl:attribute name='href'><xsl:value-of select='$library_name'/>?a=b&amp;rt=r&amp;s=<xsl:value-of select='$serviceName'/>&amp;c=<xsl:value-of select='$collName'/>&amp;cl=<xsl:value-of select='@nodeID'/></xsl:attribute><xsl:value-of disable-output-escaping="yes" select="metadataList/metadata[@name='Title']"/></a></td>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  

<!-- processing for the recursive bit -->
<!-- if interleave=true, process all child nodes and documents, else just do nodes -->


  <xsl:template match="classifierNode" mode="process-all-children">
    <xsl:param name="collName"/>
    <xsl:param name="serviceName"/>
    <!-- only do this if there are children -->
    <xsl:if test="classifierNode|documentNode">
      <td>
      <table>  
	<xsl:for-each select='classifierNode|documentNode'>
	  <tr valign='top'><xsl:apply-templates select='.'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	  <xsl:if test='name()="classifierNode"'>
	    <tr valign='top'><td><xsl:text> </xsl:text></td><xsl:apply-templates select='.' mode='process-all-children'><xsl:with-param name='collName' select='$collName'/><xsl:with-param name='serviceName' select='$serviceName'/></xsl:apply-templates></tr>
	  </xsl:if>	      
	</xsl:for-each>
      </table>
      </td>
    </xsl:if>
  </xsl:template>
    
</xsl:stylesheet>